@@ -7,7 +7,7 @@ class BeakerException(Exception):
 class CreationAbortedError(Exception):
     """deprecated."""
 
-class InvalidCacheBackendError(BeakerException):
+class InvalidCacheBackendError(BeakerException, ImportError):
     pass
 
 
@@ -17,3 +17,7 @@ class MissingCacheParameter(BeakerException):
 
 class LockError(BeakerException):
     pass
+
+class InvalidCryptoBackendError(BeakerException, ImportError):
+    def __init__(self):
+        Exception.__init__('No supported crypto implementation was found')
\ No newline at end of file
